classdef Roi < handle
  % Roi
  %   Region of interest
  %
  % Methods:
  %   sensorRows - Get the number of rows in the image sensor
  %   setSensorRows - Set the number of rows in the image sensor
  %   sensorCols - Get the number of columns in the image sensor
  %   setSensorCols - Set the number of columns in the image sensor
  %   getRowOffset - Get the row offset in pixels
  %   setRowOffset - Set the row offset in pixels
  %   getColOffset - Get the column offset in pixels
  %   setColOffset - Set the column offset in pixels
  %   getImgRows - Get the number of rows in the output image
  %   setImgRows - Set the number of rows in the output image
  %   getImgCols - Get the number of columns in the output image
  %   setImgCols - Set the number of columns in the output image
  %

  properties(Access=protected)
    mPtr = uint64(0);
  end

  methods(Access=public)
    function obj = Roi(varargin)
      % Roi
      %   Construct new roi class
      %
      % ----------
      %
      %   Default construct roi
      %

      if nargin == 1 && isa(varargin{1}, 'uint64')
        obj.mPtr = varargin{1};
      else
        error("Can't construct empty object");
      end
    end


    function delete(obj)
      if obj.mPtr ~= 0
        tof.mex('tof_roi_delete', obj.mPtr);
        obj.mPtr = 0;
      end
    end

    function ptr = get_object_ptr(obj)
      ptr = obj.mPtr;
    end

    function ret_val = sensorRows(obj)
      % sensorRows
      %   Get the number of rows in the image sensor
      %
      % Output:
      %   ret_val - numeric - Number of rows
      %

      ret_val = tof.mex('tof_roi_sensor_rows', obj.mPtr);
      ret_val = double(ret_val);
    end

    function ret_val = sensorCols(obj)
      % sensorCols
      %   Get the number of columns in the image sensor
      %
      % Output:
      %   ret_val - numeric - Number of columsn
      %

      ret_val = tof.mex('tof_roi_sensor_cols', obj.mPtr);
      ret_val = double(ret_val);
    end

    function ret_val = getRowOffset(obj)
      % getRowOffset
      %   Get the row offset in pixels
      %
      % Output:
      %   ret_val - numeric - Row offset
      %

      ret_val = tof.mex('tof_roi_get_row_offset', obj.mPtr);
      ret_val = double(ret_val);
    end

    function setRowOffset(obj, row_offset)
      % setRowOffset
      %   Set the row offset in pixels
      %
      % Inputs:
      %   row_offset - numeric - Row offset
      %

      tof.mex('tof_roi_set_row_offset', obj.mPtr, row_offset);
    end

    function ret_val = getColOffset(obj)
      % getColOffset
      %   Get the column offset in pixels
      %
      % Output:
      %   ret_val - numeric - Column offset
      %

      ret_val = tof.mex('tof_roi_get_col_offset', obj.mPtr);
      ret_val = double(ret_val);
    end

    function setColOffset(obj, col_offset)
      % setColOffset
      %   Set the column offset in pixels
      %
      % Inputs:
      %   col_offset - numeric - Column offset
      %

      tof.mex('tof_roi_set_col_offset', obj.mPtr, col_offset);
    end

    function ret_val = getImgRows(obj)
      % getImgRows
      %   Get the number of rows in the output image
      %
      % Output:
      %   ret_val - numeric - Image rows
      %

      ret_val = tof.mex('tof_roi_get_img_rows', obj.mPtr);
      ret_val = double(ret_val);
    end

    function setImgRows(obj, img_rows)
      % setImgRows
      %   Set the number of rows in the output image
      %
      % Inputs:
      %   img_rows - numeric - Image rows
      %

      tof.mex('tof_roi_set_img_rows', obj.mPtr, img_rows);
    end

    function ret_val = getImgCols(obj)
      % getImgCols
      %   Get the number of columns in the output image
      %
      % Output:
      %   ret_val - numeric - Image columns
      %

      ret_val = tof.mex('tof_roi_get_img_cols', obj.mPtr);
      ret_val = double(ret_val);
    end

    function setImgCols(obj, img_cols)
      % setImgCols
      %   Set the number of columns in the output image
      %
      % Inputs:
      %   img_cols - numeric - Image columns
      %

      tof.mex('tof_roi_set_img_cols', obj.mPtr, img_cols);
    end

  end
end
